@@ -75,6 +75,8 @@ class SourceBase(CompanyAssetModel):
             data["flow"] = []
         if "tags" in data and data["tags"] is None:
             data["tags"] = []
+        if "category" in data and data["category"] is None:
+            data["category"] = ""
         return data
 
     @property
