@@ -26,7 +26,7 @@ class ChainOfThoughtInChatRequest(BaseModel):
     id: Optional[StrObjectId] = Field(default=None, description="The id of the chain of thought")
     trigger: ChainOfThoughtInChatTrigger
     trigger_id : str = Field(description="The id of the trigger which could be a message_id or a workflow assigned to chat link id")
-    chatty_ai_agent_id : StrObjectId = Field(description="The chatty ai agent at the moment of triggering the chain of thought")
+    chatty_ai_agent_id : str = Field(description="The chatty ai agent at the moment of triggering the chain of thought")
     chain_of_thought : Optional[str] = Field(default=None, description="The chain of thought")
     name: str = Field(description="A title for the chain of thought", alias="title")
 
