@@ -15,8 +15,17 @@ class ExampleElement(BaseModel):
     type: ExampleElementType = Field(..., description="Type of the element")
     content: str = Field(..., description="Content of the element")
 
+    def to_string(self) -> str:
+        return self.type.value + ": " + self.content
+
 class ChatExample(AiAgentComponent):
     """Example conversation for training the AI agent"""
     content: List[ExampleElement] = Field(..., description="Sequence of elements in this example")
     is_essential: bool = Field(default=False, description="Whether the example is essential for the ai agent to work")
+    is_training_example: bool = Field(default=True, description="Whether the example is a training example or just a test example")
 
+    def to_string(self) -> str:
+        result = ""
+        for element in self.content:
+            result += element.to_string() + "\n"
+        return result
\ No newline at end of file
