@@ -18,8 +18,8 @@ class ExecutionContext(BaseModel):
     event_time: Optional[datetime] = None
     company_id: StrObjectId
 
-    @property
-    def chatty_company_id(self) -> StrObjectId:
+    @staticmethod
+    def chatty_company_id() -> StrObjectId:
         return "000000000000000000000000"
 
     @property
